@@ -4,7 +4,7 @@ import logging as _logging
 
 from . import spells, types
 from ._common import DEFAULT_PRIORITY, from_date, to_date
-from ._group import TodoGroup
+from ._group import MetadataCheck, TodoGroup
 from ._magic import MagicTodoMixin
 from ._todo import Todo
 
@@ -12,6 +12,7 @@ from ._todo import Todo
 __all__ = [
     "DEFAULT_PRIORITY",
     "MagicTodoMixin",
+    "MetadataCheck",
     "Todo",
     "TodoGroup",
     "from_date",
@@ -22,6 +23,6 @@ __all__ = [
 
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.8.5"
+__version__ = "0.9.0"
 
 _logging.getLogger(__name__).addHandler(_logging.NullHandler())
