@@ -2,21 +2,31 @@
 
 from __future__ import annotations
 
+from dataclasses import dataclass
 import datetime as dt
 from logging import Logger
 from pathlib import Path
-from typing import Generic, Iterable, Iterator, Mapping, Type
+from typing import Generic, Iterable, Iterator, Type
 
 from eris import Err
 from metaman import cname
 from typist import PathLike
 
-from .types import MetadataChecker, Priority, T
+from .types import MetadataFunc, Priority, T
 
 
 logger = Logger(__name__)
 
 
+@dataclass
+class MetadataCheck:
+    """Wrapper for the MetadataFunc type."""
+
+    key: str
+    check: MetadataFunc = lambda _: True
+    required: bool = True
+
+
 class TodoGroup(Generic[T]):
     """Manages a group of Todo objects."""
 
@@ -113,7 +123,7 @@ class TodoGroup(Generic[T]):
         desc: str = None,
         done_date: dt.date = None,
         done: bool = None,
-        metadata_checks: Mapping[str, MetadataChecker] = None,
+        metadata_checks: Iterable[MetadataCheck] = (),
         priorities: Iterable[Priority] = (),
         projects: Iterable[str] = (),
     ) -> TodoGroup:
@@ -157,17 +167,20 @@ class TodoGroup(Generic[T]):
             if done is not None and todo.done != done:
                 continue
 
-            if metadata_checks is not None:
-                for mkey, check in metadata_checks.items():
-                    if mkey not in todo.metadata:
-                        skip_this_todo = True
-                        break
+            for mcheck in metadata_checks:
+                key_not_found = mcheck.key not in todo.metadata
+                if mcheck.required and key_not_found:
+                    skip_this_todo = True
+                    break
 
-                    mvalue = todo.metadata[mkey]
-                    assert isinstance(mvalue, str)
-                    if not check(mvalue):
-                        skip_this_todo = True
-                        break
+                if key_not_found:
+                    continue
+
+                mvalue = todo.metadata[mcheck.key]
+                assert isinstance(mvalue, str)
+                if not mcheck.check(mvalue):
+                    skip_this_todo = True
+                    break
 
             if skip_this_todo:
                 continue
