@@ -11,7 +11,7 @@ from syrupy.assertion import SnapshotAssertion as Snapshot
 from magodo import TodoGroup
 
 from .data import get_all_todo_paths
-from .shared import MagicTodo
+from .shared import MOCK_TODO_KWARGS, MagicTodo
 
 
 params = mark.parametrize
@@ -19,17 +19,19 @@ params = mark.parametrize
 
 @params("todo_file", get_all_todo_paths())
 @params(
-    "kwargs",
+    "filter_kwargs",
     [
-        param({}, id="none"),
-        param({"desc": "Double colons"}, id="desc"),
+        param({}, id="no-filter-kwargs"),
+        param({"desc": "Double colons"}, id="filter-kwarg-desc"),
         param({"contexts": ["high"]}, id="ctx"),
     ],
 )
 def test_group_from_path(
-    snapshot: Snapshot, todo_file: Path, kwargs: dict[str, Any]
+    snapshot: Snapshot, todo_file: Path, filter_kwargs: dict[str, Any]
 ) -> None:
     """Test the TodoGroup.from_path() function."""
     todo_group = TodoGroup.from_path(MagicTodo, todo_file)
-    todo_group = todo_group.filter_by(**kwargs)
-    assert [repr(todo) for todo in todo_group] == snapshot
+    todo_group = todo_group.filter_by(**filter_kwargs)
+    assert [
+        repr(todo.new(**MOCK_TODO_KWARGS)) for todo in todo_group
+    ] == snapshot
